ACCESS_TOKEN_VALIDITY=900
AUDIENCE="https://iam.services.indicoinnovation.pt"
AUTH_SERVER="iam.services.indicoinnovation.pt"

# Scopes
IAM_ADMIN = "iam.admin"
AUTH_CONNECT = "auth.connect"
TOKEN_GENERATE = "integrations.generate_jwt"
TOKEN_VALIDATE = "integrations.validate_jwt"
MFA_ADMIN = "mfa.admin"
MFA_GENERATE = "mfa.generate"
MFA_VALIDATE = "mfa.validate"

ERR_NOT_ALLOWED = "service account not allowed to make this request"